summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--configure.ac2
-rw-r--r--decoders/Makefile.am2
-rw-r--r--decoders/usb_packet/Makefile.am (renamed from decoders/usb_protocol/Makefile.am)2
-rw-r--r--decoders/usb_packet/__init__.py (renamed from decoders/usb_protocol/__init__.py)2
-rw-r--r--decoders/usb_packet/pd.py (renamed from decoders/usb_protocol/pd.py)16
5 files changed, 12 insertions, 12 deletions
diff --git a/configure.ac b/configure.ac
index 0fd8918..ca85648 100644
--- a/configure.ac
+++ b/configure.ac
@@ -181,7 +181,7 @@ AC_CONFIG_FILES([Makefile
decoders/transitioncounter/Makefile
decoders/uart/Makefile
decoders/uart_dump/Makefile
- decoders/usb_protocol/Makefile
+ decoders/usb_packet/Makefile
decoders/usb_signalling/Makefile
decoders/xfp/Makefile
])
diff --git a/decoders/Makefile.am b/decoders/Makefile.am
index ea8091f..34843f2 100644
--- a/decoders/Makefile.am
+++ b/decoders/Makefile.am
@@ -49,7 +49,7 @@ SUBDIRS = \
transitioncounter \
uart \
uart_dump \
- usb_protocol \
+ usb_packet \
usb_signalling \
xfp
diff --git a/decoders/usb_protocol/Makefile.am b/decoders/usb_packet/Makefile.am
index 7e1baa6..f095957 100644
--- a/decoders/usb_protocol/Makefile.am
+++ b/decoders/usb_packet/Makefile.am
@@ -18,7 +18,7 @@
## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
##
-pkgdatadir = $(DECODERS_DIR)/usb_protocol
+pkgdatadir = $(DECODERS_DIR)/usb_packet
dist_pkgdata_DATA = __init__.py pd.py
diff --git a/decoders/usb_protocol/__init__.py b/decoders/usb_packet/__init__.py
index 5fa66f6..555dc7f 100644
--- a/decoders/usb_protocol/__init__.py
+++ b/decoders/usb_packet/__init__.py
@@ -19,7 +19,7 @@
##
'''
-USB (low-speed and full-speed) protocol decoder.
+USB (low-speed and full-speed) packet protocol decoder.
Protocol layer (USB spec, chapter 8):
diff --git a/decoders/usb_protocol/pd.py b/decoders/usb_packet/pd.py
index 92ee77a..b8c668e 100644
--- a/decoders/usb_protocol/pd.py
+++ b/decoders/usb_packet/pd.py
@@ -19,7 +19,7 @@
## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
##
# USB (low-speed and full-speed) protocol decoder
import sigrokdecode as srd
@@ -96,13 +96,13 @@ def packet_decode(packet):
class Decoder(srd.Decoder):
api_version = 1
- id = 'usb_protocol'
- name = 'USB protocol'
- longname = 'Universal Serial Bus (LS/FS) protocol'
- desc = 'USB (low-speed and full-speed) serial protocol.'
+ id = 'usb_packet'
+ name = 'USB packet'
+ longname = 'Universal Serial Bus (LS/FS) packet'
+ desc = 'USB (low-speed and full-speed) packet protocol.'
license = 'gplv2+'
inputs = ['usb_signalling']
- outputs = ['usb_protocol']
+ outputs = ['usb_packet']
probes = []
optional_probes = []
options = {
@@ -121,8 +121,8 @@ class Decoder(srd.Decoder):
def start(self, metadata):
self.samplerate = metadata['samplerate']
- self.out_proto = self.add(srd.OUTPUT_PROTO, 'usb_protocol')
- self.out_ann = self.add(srd.OUTPUT_ANN, 'usb_protocol')
+ self.out_proto = self.add(srd.OUTPUT_PROTO, 'usb_packet')
+ self.out_ann = self.add(srd.OUTPUT_ANN, 'usb_packet')
def report(self):
pass
@@ -19,7 +19,7 @@
## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
##
-# USB (low-speed and full-speed) protocol decoder
+# USB (low-speed and full-speed) packet protocol decoder
import sigrokdecode as srd